import { Button, Center, Input, Spinner } from "@chakra-ui/react";
import "../../resources/styles/loginPage.scss"
import { observer } from "mobx-react"
import { LoginPageStore } from "./LoginPageStore";
import { useRef } from "react";

const store = new LoginPageStore();
export const LoginPage = observer(() => {

    const loginRef = useRef<HTMLInputElement>(null);
    const passwordRef = useRef<HTMLInputElement>(null);

    const handleKeyDown = (key: string) => {
        if (key === "ArrowDown") {
            if (document.activeElement === loginRef.current) {
                passwordRef.current?.focus();
            }
        } else if (key === "ArrowUp") {
            if (document.activeElement === passwordRef.current) {
                loginRef.current?.focus();
            }
        }

        else if (key === "Enter") store.handleLogin();
    };


    return (
        <div className="container_wrapper">
            <div className="login_container">
                <h1>Вход</h1>
                {store.isLoading
                    ? <>
                        <div style={{
                            height: 128,
                            display: 'flex',
                            justifyContent: 'center',
                            alignItems: 'center'
                        }}>
                            <Spinner size="xl" />
                        </div>
                    </>
                    : <>
                        <Input
                            ref={loginRef}
                            placeholder="Логин"
                            value={store.login}
                            onChange={e => store.setLogin(e.target.value)}
                            onKeyDown={x => handleKeyDown(x.key)}
                            marginBottom={5} />
                        <Input
                            ref={passwordRef}
                            placeholder="Пароль"
                            type="password"
                            marginBottom={7}
                            onKeyDown={x => handleKeyDown(x.key)}
                            value={store.password}
                            onChange={e => store.setPassword(e.target.value)} />
                    </>}
                <Center paddingBottom={7}>
                    <Button
                        onClick={() => store.handleLogin()}
                        isLoading={store.isLoading}
                        loadingText={"Захожу..."}
                        variant='outline'
                        size='md'
                        width={100}>Войти
                    </Button>
                </Center>
            </div>
        </div>);
})